FileReader class
Constructors
- FileReader({String rootPath = './', String assetsPath = './assets', String libPath = './lib'})
Properties
- assetsDir → Directory
-
no setter
- assetsPath ↔ String
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- libDir → Directory
-
no setter
- libPath ↔ String
-
latefinal
- rootDir → Directory
-
no setter
- rootPath ↔ String
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeImages(
{bool ignoreDynamicAssets = false, required List< ImageEntityStatistics> imageEntities, required List<FileSystemEntity> configureEntities, required List<FileSystemEntity> libEntites}) → List<ImageEntityStatistics> -
deleteImage(
List< ImageEntityStatistics> imageEntities) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAssetsEntities(
) → Future< List< ImageEntityStatistics> > -
readLibFileEntity(
) → Future< List< FileSystemEntity> > -
readRootFileEntity(
) → Future< List< FileSystemEntity> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited